@@ -1,3 +1,19 @@
+# Copyright 2024 DARWIN EU®
+#
+# This file is part of TreatmentPatterns
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 splitPathItems <- function(treatmentPathways) {
   data <- treatmentPathways %>%
     rowwise() %>%
@@ -193,32 +209,3 @@ createSankeyDiagram <- function(treatmentPathways, groupCombinations = FALSE, co
     ...
   )
 }
-
-#' createSankeyDiagram2
-#' 
-#' DEPRECATED Create sankey diagram.
-#'
-#' @template param_treatmentPathways
-#' @template param_groupCombinations
-#' @param colors (`character(n)`) Vector of hex color codes.
-#' @param ... Paramaters for \link[networkD3]{sankeyNetwork}.
-#'
-#' @return (`htmlwidget`)
-#' @export
-#'
-#' @examples
-#' # Dummy data, typically read from treatmentPathways.csv
-#' treatmentPathways <- data.frame(
-#'   path = c("Acetaminophen", "Acetaminophen-Amoxicillin+Clavulanate",
-#'            "Acetaminophen-Aspirin", "Amoxicillin+Clavulanate", "Aspirin"),
-#'   freq = c(206, 6, 14, 48, 221),
-#'   sex = rep("all", 5),
-#'   age = rep("all", 5),
-#'   index_year = rep("all", 5)
-#' )
-#' 
-#' createSankeyDiagram(treatmentPathways)
-createSankeyDiagram2 <- function(treatmentPathways, groupCombinations = FALSE, colors = NULL, ...) {
-  warning("`createSankeyDiagram2()` is deprecated, please use `createSankeyDiagram()`")
-  createSankeyDiagram(treatmentPathways, groupCombinations, colors, ...)
-}
