@@ -1,3 +1,19 @@
+# Copyright 2024 DARWIN EU®
+#
+# This file is part of TreatmentPatterns
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 #' createSunburstPlot
 #' 
 #' New sunburstPlot function
@@ -35,38 +51,6 @@ createSunburstPlot <- function(treatmentPathways, groupCombinations = FALSE, ...
   )
 }
 
-
-#' createSunburstPlot2
-#' 
-#' DEPRECATED New sunburstPlot function
-#'
-#' @template param_treatmentPathways 
-#' @template param_groupCombinations
-#' @param ... Paramaters for \link[sunburstR]{sunburst}.
-#'
-#' @return (`htmlwidget`)
-#' @export
-#'
-#' @examples
-#' # Dummy data, typically read from treatmentPathways.csv
-#' treatmentPatwhays <- data.frame(
-#'   path = c("Acetaminophen", "Acetaminophen-Amoxicillin+Clavulanate",
-#'            "Acetaminophen-Aspirin", "Amoxicillin+Clavulanate", "Aspirin"),
-#'   freq = c(206, 6, 14, 48, 221),
-#'   sex = rep("all", 5),
-#'   age = rep("all", 5),
-#'   index_year = rep("all", 5)
-#' )
-#' 
-#' createSunburstPlot2(treatmentPatwhays)
-createSunburstPlot2 <- function(treatmentPathways, groupCombinations = FALSE, ...) {
-  warning(
-    "`createSunburstPlot2()` is deprecated, please use `createSunburstPlot()`\n`createSunburstPlot2()` will be removed in 2.7.0"
-  )
-  TreatmentPatterns::createSunburstPlot(treatmentPathways, groupCombinations, ...)
-}
-
-
 validateCreateSunburstPlot <- function() {
   args <- eval(
     expr = expression(mget(names(formals()))),
