@@ -4,7 +4,8 @@ SELECT
   @resultSchema.@cohortTable.cohort_start_date,
   @resultSchema.@cohortTable.cohort_end_date,
   YEAR(@resultSchema.@cohortTable.cohort_start_date) - @cdmSchema.person.year_of_birth AS age,
-  @cdmSchema.concept.concept_name AS sex
+  @cdmSchema.concept.concept_name AS sex,
+  subject_id_origin
 FROM
   @resultSchema.@cohortTable
 INNER JOIN @cdmSchema.person
@@ -18,6 +19,15 @@ INNER JOIN
     WHERE @resultSchema.@cohortTable.cohort_definition_id IN (@targetCohortId)
   ) AS cross_sec
   ON cross_sec.subject_id = @resultSchema.@cohortTable.subject_id
+INNER JOIN
+  (
+    SELECT
+      ROW_NUMBER() OVER (PARTITION BY subject_id) AS subject_id,
+      CAST(subject_id AS VARCHAR) AS subject_id_origin
+    FROM cohort_table
+    GROUP BY subject_id
+  ) org_subject_table
+  ON subject_id_origin = @resultSchema.@cohortTable.subject_id
 WHERE
   cohort_definition_id IN (@cohortIds)
-  AND DATEDIFF(d, cohort_start_date, cohort_end_date) >= @minEraDuration
+  AND DATEDIFF(d, cohort_start_date, cohort_end_date) >= @minEraDuration;
\ No newline at end of file
