@@ -45,6 +45,32 @@ test_that("groupCombinations: TRUE", {
     sort()
   
   expect_identical(pLabels, actualLabels)
+  
+  df <- data.frame(
+    path = c(
+      "A-B",
+      "A+B",
+      "A-B+C",
+      "A+B-C",
+      "A+B+C",
+      "A-B+C-D",
+      "Z_Y-A",
+      "Z_Y+A",
+      "1_2-A",
+      "1_2+A"
+    ),
+    freq = rep(100, 10)
+  )
+  
+  p <- createSankeyDiagram(treatmentPathways = df, groupCombinations = TRUE)
+  labels <- stringr::str_remove_all(string = p$x$nodes$name, pattern = "\\d\\.")
+  
+  expect_true(all(labels %in% c("A", "B", "C", "D", "Z_Y", "1_2", "Combination", "Stopped")))
+  
+  expect_identical(
+    p$x$nodes$name,
+    c("1.1_2", "1.A", "1.Combination", "1.Z_Y", "2.A", "2.B", "2.Combination", "2.C", "2.Stopped", "3.Stopped", "3.D")
+  )
 })
 
 test_that("colors", {
@@ -52,9 +78,36 @@ test_that("colors", {
   
   p <- createSankeyDiagram(treatmentPathways = dummyData, colors = actualColors)
   
-  pColors <- p$x$options$colourScale
+  pColors <- unlist(stringr::str_extract_all(string = p$x$options$colourScale, "\\#\\w{6}"))
   
-  expect_identical(pColors, actualColors)
+  expect_true(all(pColors %in% actualColors))
+  
+  actualColors <- list(
+    A = "#0FFFF0",
+    B = "#F0F0F0",
+    C = "#FF0000",
+    D = "#FFF000",
+    E = "#00FF00",
+    `F` = "#F000FF",
+    `A+Z` = "#0000FF",
+    `D+Z` = "#0FF0F0"
+  )
+
+  p <- createSankeyDiagram(treatmentPathways = dummyData, colors = actualColors)
+  
+  pColors <- unlist(stringr::str_extract_all(string = p$x$options$colourScale, "\\#\\w{6}"))
+  labels <- unlist(stringr::str_extract_all(string = p$x$options$colourScale, "\\'\\d\\.[\\w\\+\\-]+\\'"))
+  labels <- stringr::str_remove_all(string = labels, pattern = "[\\'|\\d{1}\\.]")
+  labels <- unique(labels)
+  
+  l <- as.list(unique(pColors))
+  names(l) <- labels
+  l <- l[names(l) != "Stopped"]
+  
+  expect_identical(
+    actualColors[order(names(actualColors))],
+    l[order(names(l))]
+  )
 })
 
 test_that("2 path levels", {
