@@ -27,7 +27,7 @@ test_that("CohortGenerator", {
   )
 
   expect_true(
-    file.exists(file.path(tempDir, "summaryStatsTherapyDuration.csv"))
+    file.exists(file.path(tempDir, "summaryEventDuration.csv"))
   )
 
   expect_true(
@@ -63,7 +63,7 @@ test_that("CDMConnector", {
   )
 
   expect_true(
-    file.exists(file.path(tempDir, "summaryStatsTherapyDuration.csv"))
+    file.exists(file.path(tempDir, "summaryEventDuration.csv"))
   )
 
   expect_true(
