@@ -49,7 +49,7 @@ test_that("outputPath", {
   )
 
   expect_true(
-    file.exists(file.path(tempDirLocal, "summaryStatsTherapyDuration.csv"))
+    file.exists(file.path(tempDirLocal, "summaryEventDuration.csv"))
   )
 
   expect_true(
@@ -305,7 +305,7 @@ test_that("outputPath", {
   )
 
   expect_true(
-    file.exists(file.path(tempDirLocal, "summaryStatsTherapyDuration.csv"))
+    file.exists(file.path(tempDirLocal, "summaryEventDuration.csv"))
   )
 
   expect_true(
@@ -531,7 +531,6 @@ test_that("censorType", {
   DBI::dbDisconnect(globals$con, shutdown = TRUE)
 })
 
-
 test_that("counts", {
   skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
@@ -595,4 +594,33 @@ test_that("counts", {
   }) %>% unlist() %>% sum()
   
   expect_identical(totalAll, totalYears)
-})
\ No newline at end of file
+  
+  Andromeda::close(andromeda)
+  DBI::dbDisconnect(globals$con, shutdown = TRUE)
+})
+
+test_that("attrition", {
+  skip_on_cran()
+  skip_if_not(ableToRun()$CDMC)
+
+  globals <- generateCohortTableCDMC()
+  
+  andromeda <- TreatmentPatterns::computePathways(
+    cohorts = globals$cohorts,
+    cohortTableName = globals$cohortTableName,
+    cdm = globals$cdm
+  )
+  
+  tempDirLocal <- file.path(tempdir(), "output")
+  suppressWarnings(
+    TreatmentPatterns::export(
+      andromeda = andromeda,
+      outputPath = tempDirLocal
+    )
+  )
+  
+  expect_true(file.exists(file.path(tempDirLocal, "attrition.csv")))
+  
+  Andromeda::close(andromeda)
+  DBI::dbDisconnect(globals$con, shutdown = TRUE)
+})
