@@ -27,7 +27,7 @@ test_that("A", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 30,
@@ -79,7 +79,7 @@ test_that("A-B", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 30,
@@ -133,7 +133,7 @@ test_that("A-B-C", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 30,
@@ -186,7 +186,7 @@ test_that("A-B+C", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 30,
@@ -239,7 +239,7 @@ test_that("A+B-C", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 30,
@@ -292,7 +292,7 @@ test_that("A-A+B", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 30,
@@ -346,7 +346,7 @@ test_that("A-B-A-B", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 30,
@@ -399,7 +399,7 @@ test_that("A-B-A", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 30,
@@ -452,7 +452,7 @@ test_that("A-B-B, collapse to A-B", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 30,
@@ -505,7 +505,7 @@ test_that("A-B-B", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 30,
@@ -558,7 +558,7 @@ test_that("A+B-A", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 30,
@@ -611,7 +611,7 @@ test_that("A-A-B", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 30,
@@ -664,7 +664,7 @@ test_that("A-A-B, collapse to A-B", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 30,
@@ -718,7 +718,7 @@ test_that("A+B-A+B, collapse to A+B", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 30,
@@ -772,7 +772,7 @@ test_that("A+B-A+B", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 30,
@@ -824,7 +824,7 @@ test_that("A-A+B-B", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 5,
@@ -877,7 +877,7 @@ test_that("A-A-C-A+B+C-C", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 5,
@@ -930,7 +930,7 @@ test_that("A-A+B+C-A+C-C", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 1,
     eraCollapseSize = 5,
     combinationWindow = 5,
@@ -984,7 +984,7 @@ test_that("A-A+C-C-B+C-C", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 5,
     combinationWindow = 1,
@@ -1035,7 +1035,7 @@ test_that("start event == start target", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 30,
     combinationWindow = 30,
@@ -1086,7 +1086,7 @@ test_that("end event == end target", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 30,
     combinationWindow = 30,
@@ -1137,7 +1137,7 @@ test_that("start-end event == start-end target", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 30,
     combinationWindow = 30,
@@ -1188,7 +1188,7 @@ test_that("start event < start target", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 30,
     combinationWindow = 30,
@@ -1230,7 +1230,7 @@ test_that("start event < start target, periodPrior = 60", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 60,
+    indexDateOffset = 60,
     minEraDuration = 0,
     eraCollapseSize = 30,
     combinationWindow = 30,
@@ -1281,7 +1281,7 @@ test_that("start event > end target", {
     cohortTableName = "cohort_table",
     cdm = cdm,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 30,
     combinationWindow = 30,
@@ -1327,7 +1327,7 @@ test_that("collapse A-B-B-B to A-A+B-B", {
     cdm = cdm,
     tempEmulationSchema = NULL,
     includeTreatments = "startDate",
-    periodPriorToIndex = 0,
+    indexDateOffset = 0,
     minEraDuration = 30,
     eraCollapseSize = 30,
     combinationWindow = 30,
